@@ -1,14 +1,20 @@
 from importlib import import_module
 import os
 import string
+import ast
+import astor
+import textwrap
 from jinja2 import Template
 
 from .helper import copy_template, search_model
 
 
-def g_project(name):
+def g_project(name: str):
     """
-    Fungsi untuk membuat project.
+    Functions for creating projects.
+
+    :param name: project name.
+
     """
 
     print("Creating %r project..." % name)
@@ -24,12 +30,15 @@ def g_project(name):
         fp.write(new)
 
 
-def g_api(name):
+def g_api(name: str):
     """
-    Fungsi untuk membuat API.
+    Functions for creating APIs.
+
+    :param name: REST API name.
+
     """
 
-    print("Creating rest api %r... " % name, end="")
+    print("Creating API %r... " % name, end="")
     copy_template("api", "api")
     old_filename = os.path.join("api", "name.py")
     with open(old_filename) as fp:
@@ -45,14 +54,17 @@ def g_api(name):
     print("(done)")
 
 
-def g_api_crud(name):
+def g_api_crud(name: str):
     """
-    Fungsi untuk membuat REST API.
+    Function for creating REST API.
+
+    :param name: REST API name.
+
     """
 
     src_model = search_model(name)
     src_schema = src_model.replace("models", "schema", 1)
-    print("Creating REST API (crud) %r... " % name, end="")
+    print("Creating REST API %r... " % name, end="")
     copy_template("crud", "api")
     old_filename = os.path.join("api", "name.py")
     with open(old_filename) as fp:
@@ -73,9 +85,12 @@ def g_api_crud(name):
     print("(done)")
 
 
-def g_blueprint(name):
+def g_blueprint(name: str):
     """
-    Fungsi untuk membuat blueprint boilerplate.
+    Function for creating blueprints.
+
+    :param name: blueprint name.
+
     """
 
     print("Creating blueprint %r... " % name, end="")
@@ -93,9 +108,13 @@ def g_blueprint(name):
     print("(done)")
 
 
-def g_schema(src, models):
+def g_schema(src: str, models: list):
     """
-    Fungsi untuk membuat model schema.
+    Function for creating schema models.
+
+    :param src: source model.
+    :param models: list of ORM models in your model module.
+
     """
 
     if not models:
@@ -103,8 +122,51 @@ def g_schema(src, models):
 
     srcfile = import_module(src).__file__.replace("models" + os.sep, "schema" + os.sep)
     if os.path.isfile(srcfile):
-        choice = input("File %r exist, apakah mau di timpa? (y/N): " % src).lower()
-        if choice != "y":
+        with open(srcfile) as fp:
+            data = fp.read()
+
+        node_import = None
+        klass = []
+        root = ast.parse(data, filename=os.path.basename(srcfile))
+        for node in ast.iter_child_nodes(root):
+            if isinstance(node, ast.ImportFrom) and node.module == "models.user":
+                node_import = node
+
+            elif isinstance(node, ast.ClassDef):
+                for b in node.bases:
+                    if b.value.id == "ma" and node.name.endswith("Schema"):
+                        name = node.name.replace("Schema", "")
+                        klass.append(name)
+
+        for k in klass:
+            if k in models:
+                models.remove(k)
+
+        if models and node_import is not None:
+            print("Creating schema for %r... " % src, end="")
+            node_import.names = []
+            for m in klass + models:
+                m = ast.alias(name=m, asname=None)
+                node_import.names.append(m)
+
+            tmp = textwrap.dedent(
+                """\
+            {% for name in model_list %}
+            class {{name}}Schema(ma.SQLAlchemyAutoSchema):
+                class Meta:
+                    model = {{name}}
+            {% endfor %}
+            """
+            )
+            t = Template(tmp)
+            new_models = t.render(model_list=models)
+            new_data = astor.to_source(root) + "\n" + new_models
+            with open(srcfile, "w") as fp:
+                fp.write(new_data)
+
+            print("(done)")
+
+        if klass:
             return
 
     print("Creating schema for %r... " % src, end="")
@@ -128,9 +190,12 @@ def g_schema(src, models):
     print("(done)")
 
 
-def g_command(name):
+def g_command(name: str):
     """
-    Fungsi untuk membuat command boilerplate.
+    Function to create boilerplate command.
+
+    :param name: command name.
+
     """
 
     print("Creating command %r..." % name, end="")
